import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

from mns_common.db.MongodbUtil import MongodbUtil
from functools import lru_cache

mongodb_util_27017 = MongodbUtil('27017')
mongodb_util_21019 = MongodbUtil('27019')


# 获取数据库链接 27017
@lru_cache(maxsize=None)
def get_db(str_day):
    trade_date_list = mongodb_util_27017.find_query_data('trade_date_list',
                                                         query={"_id": str_day, 'tag': False})
    tag = trade_date_list.shape[0] > 0
    if tag:
        return mongodb_util_27017
    else:
        return mongodb_util_21019


# 获取str_day日期 实时数据 的 field 最小值
@lru_cache(maxsize=None)
def get_realtime_quotes_now_min_number(str_day, field, symbol):
    if field is None:
        field = 'number'
    if symbol is None:
        symbol = '000001'
    realtime_quotes_db_name = 'realtime_quotes_now_' + str_day
    db = get_db(str_day)
    min_str_now_date = str_day + " 09:26:00"
    query = {'symbol': symbol, "str_now_date": {"$gte": min_str_now_date}}
    df = db.ascend_query(query, realtime_quotes_db_name, field, 1)
    if df is None or df.shape[0] == 0:
        return 1
    else:
        return list(df[field])[0]


# 获取str_day日期 实时数据 的 field 最大值
@lru_cache(maxsize=None)
def get_realtime_quotes_now_max_number(str_day, field, symbol):
    if field is None:
        field = 'number'
    if symbol is None:
        symbol = '000001'
    realtime_quotes_db_name = 'realtime_quotes_now_' + str_day
    db = get_db(str_day)
    min_str_now_date = str_day + " 09:26:00"
    query = {'symbol': symbol, "str_now_date": {"$gte": min_str_now_date}}
    df = db.descend_query(query, realtime_quotes_db_name, field, 1)
    if df is None or df.shape[0] == 0:
        return 1
    else:
        return list(df[field])[0]


if __name__ == '__main__':
    print(get_realtime_quotes_now_max_number('2024-06-04', None, None))
    print(get_realtime_quotes_now_min_number('2024-06-04', None, None))


import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 7
project_path = file_path[0:end]
sys.path.append(project_path)

# 股票类型
sh_small_normal_k_line_param = {
    # 涨停
    'zt_chg': 9
}



from enum import Enum


class BlackClassify(Enum):
    # 一 交易类
    TRANSACTIONS = (1, '交易类', 'transactions', 1, 'transactions', '交易类')
    # 成交量
    AMOUNT_RISK = (1, '交易类', 'transactions', 2, 'amount_risk', '成交量风险')
    # 股东数量风险
    SHAREHOLDERS_NUMBER_RISK = (1, '交易类', 'transactions', 2, 'shareholders_number_risk', '股东数量风险')
    # 市值
    MV_RISK = (1, '交易类', 'transactions', 2, 'mv_risk', '市值风险')
    # 收盘价问题
    CLOSE_PRICE_RISK = (1, '交易类', 'transactions', 2, 'close_price_risk', '收盘价风险')

    # 二 财务类
    FINANCIAL = (1, '财务类', 'financial', 1, 'financial', '财务类')
    # 利润表+营业收入 净利润为负且营收低于1亿-最近一个会计年度经审计的净利润为负目营业收入低于1亿元，或追溯重述后最近一个会计年度净利润为负且营业收入低于!亿元
    FINANCIAL_PROBLEM_PROFIT = (1, '财务类', 'financial', 2, 'financial_problem_profit', '利润表+营业收入风险')
    # 净资产为负数,高杠杆-最近一个会计年度经审计的期未净资产为负，或追溯重述后最近，个会计年度期末净资产为负
    FINANCIAL_PROBLEM_DEBT = (1, '财务类', 'financial', 2, 'financial_problem_debt', '净资产风险')
    # 财务年报审计有问题(非标准无保留)-最近一个会计年度的财务会计报告被出具无法表示意见或否定意见的审计报告
    AUDIT_PROBLEM = (1, '财务类', 'financial', 2, 'audit_problem', '年报审计问题')
    # 财务造假 -中国证监会行政处罚决定表明公司己披露的最近一个会计年度财务报告存在虚假记载、误导性陈述或者重大遗漏，导致该年度相关则务指标实际已触及本款第一项、第一项情形
    FINANCIAL_FRAUD = (1, '财务类', 'financial', 2, ' financial_fraud', '财务造假')

    # 三 规范类
    COMPLIANCE = (1, '规范类', 'compliance', 1, 'compliance', '规范类')
    # 未在法定期限内披露年度报告或者半年度报告，且在公司股票停牌两个月内仍未披露
    UNDISCLOSED_REPORT = (1, '规范类', 'compliance', 2, 'undisclosed_report', '未披露报告')
    # 报告不保证真实准确完整 -半数以上董事无法保证年度报告或者半年度报告真实、准
    # 确、完整，且在公司股票停牌两个月内仍有半数以上董事无法保证的
    REPORT_NOT_TRUE_COMPLETE = (1, '规范类', 'compliance', 2, 'report_not_true_complete', '报告不保证真实准确完整')
    # 信息披露缺陷
    REPORT_DISCLOSED_DEFECT = (1, '规范类', 'compliance', 2, 'report_disclosure_defect', '信息披露缺陷')

    # 四 重大违法类
    MAJOR_VIOLATIONS = (1, '重大违法类', 'major_violations', 2, 'major_violations', '重大违法类')
    # 重大违法类-立案调查-损害证券市场秩序
    REGISTER_INVESTIGATE = (1, '重大违法类', 'major_violations', 2, 'register_investigate', '立案调查')
    # 重大违法类-危害安全-损害国家利益，社会公众利益
    ENDANGER_SAFETY = (1, '重大违法类', 'major_violations', 2, 'endanger_safety', '危害安全')

    # 五 自主拉黑
    SELF_SHIELD = (1, '自主拉黑', 'self_shield', 1, 'self_shield', '自主拉黑')
    # 自主拉黑—庄股
    CONTROLLED_STOCK = (1, '自主拉黑', 'self_shield', 2, 'controlled_stock', '庄股')
    # 自主拉黑—其他
    SELF_SHIELD_OTHER = (1, '自主拉黑', 'self_shield', 2, 'self_shield_other', '其他原因')

    # up_level 上一个层级  level 当前层级
    def __init__(self, up_level, up_level_name, up_level_code, level, level_code, level_name):
        self.up_level = up_level
        self.up_level_code = up_level_code
        self.up_level_name = up_level_name
        self.level = level
        self.level_name = level_name
        self.level_code = level_code



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)


# 计算 当如最大涨幅  回落的幅度 超平均价幅度
def calculate_param(real_time_quotes_now):
    # 最大涨幅
    real_time_quotes_now['max_chg'] = round(
        (((real_time_quotes_now['high'] - real_time_quotes_now['yesterday_price']) / real_time_quotes_now[
            'yesterday_price']) * 100), 2)
    # 最大涨幅与当前涨幅的差值 越大表明是拉高出货
    real_time_quotes_now['chg_fall_back'] = round(real_time_quotes_now['max_chg'] - real_time_quotes_now['chg'], 2)
    # 当前价格与今天开盘价格的差值 为负表明为下跌趋势
    real_time_quotes_now['chg_from_open'] = round(
        (((real_time_quotes_now['now_price'] - real_time_quotes_now['open']) / real_time_quotes_now[
            'open']) * 100), 2)

    if 'average_price' in real_time_quotes_now.columns:
        # 高于平均线的差值 越大表明极速拉伸
        real_time_quotes_now['diff_avg_chg'] = round(
            (((real_time_quotes_now['now_price'] - real_time_quotes_now['average_price']) / real_time_quotes_now[
                'average_price']) * 100), 2)
    else:
        real_time_quotes_now['diff_avg_chg'] = 0
    return real_time_quotes_now



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
from loguru import logger
import easytrader
from easytrader import grid_strategies
import mns_common.api.akshare.stock_bid_ask_api as stock_bid_ask_api

user = easytrader.use('ths')
user.connect(r'D:\Program Files\ths\xiadan.exe')
user.grid_strategy = grid_strategies.Xls
user.grid_strategy_instance.tmp_folder = 'C:\\custom_folder'


# 下单
def order_buy(symbol, buy_price, buy_volume):
    logger.warning("买入代码:{},买入价格:{},买入数量:{}", symbol, buy_price, buy_volume)
    user.enable_type_keys_for_editor()
    buy_result = user.buy(symbol, buy_price, buy_volume)

    return buy_result


# 自动一键打新
def auto_ipo_buy():
    user.auto_ipo()


# 获取持仓
def get_position():
    return user.position


# 卖出
def order_sell(symbol, sell_price, sell_volume):
    user.enable_type_keys_for_editor()
    sell_result = user.sell(symbol, sell_price, sell_volume)
    return sell_result


# 取消
def order_cancel(entrust_no):
    user.enable_type_keys_for_editor()
    cancel_result = user.cancel_entrust(entrust_no)
    return cancel_result


# 获取最新卖出价格
def get_last_sell_price(symbol):
    stock_bid_ask_df = stock_bid_ask_api.stock_bid_ask_em(symbol)
    buy_5 = list(stock_bid_ask_df['buy_5'])[0]
    if buy_5 != 0:
        return buy_5
    buy_4 = list(stock_bid_ask_df['buy_4'])[0]
    if buy_4 != 0:
        return buy_4

    buy_3 = list(stock_bid_ask_df['buy_3'])[0]
    if buy_3 != 0:
        return buy_3

    buy_2 = list(stock_bid_ask_df['buy_2'])[0]
    if buy_2 != 0:
        return buy_2

    buy_1 = list(stock_bid_ask_df['buy_1'])[0]
    if buy_1 != 0:
        return buy_1
    # 跌停价格
    sell_1 = list(stock_bid_ask_df['sell_1'])[0]
    if sell_1 != 0:
        return sell_1


# 获取最新价格
def get_last_buy_price(symbol):
    stock_bid_ask_df = stock_bid_ask_api.stock_bid_ask_em(symbol)
    # 用二档买入 五档成本过高
    sell_2 = list(stock_bid_ask_df['sell_2'])[0]
    if sell_2 != 0:
        return sell_2
    sell_5 = list(stock_bid_ask_df['sell_5'])[0]
    if sell_5 != 0:
        return sell_5
    sell_4 = list(stock_bid_ask_df['sell_4'])[0]
    if sell_4 != 0:
        return sell_4
    sell_3 = list(stock_bid_ask_df['sell_3'])[0]
    if sell_3 != 0:
        return sell_3
    sell_1 = list(stock_bid_ask_df['sell_1'])[0]
    if sell_1 != 0:
        return sell_1
    # 打板价格
    buy_1 = list(stock_bid_ask_df['buy_1'])[0]
    if buy_1 != 0:
        return buy_1


if __name__ == '__main__':
    # while True:
    position_df = get_position()
    print(position_df)
    # buy_result_df = order_buy('300085', '10.28', 1000)
    # print(buy_result_df)
    # auto_ipo_buy()
    # cancel_result_df = order_cancel('0111735004')
    # print(cancel_result_df)
    # sell_result_df = order_sell('300917', '24.88', 200)
    # print(sell_result_df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

# 按照上市时间对股票分类

# 股票类型
stock_type_classify_param = {
    #  上市五个交易日的股票 名字以C开头
    "new_stock": "new",
    # 交易上市6-100天的次新股票
    'sub_stock_new': "sub_new",
    # 上市 100-365天的股票
    "sub_stock": "sub",
    # 365 到无穷天的股票
    "normal_stock": "normal",
    # 一个月最大交易天数 23天 三个月 4*23+1 =93  加1是上市第一天
    'sub_stock_new_max_deal_days': 100,
    # 上市交易 100-365天次新的股票
    'sub_stock_max_days': 365,

}
